package com.ruoyi.projectCost.service;

import java.util.List;
import com.ruoyi.projectCost.domain.ProjectCost;

/**
 * projectCostService接口
 * 
 * @author ruoyi
 * @date 2023-08-14
 */
public interface IProjectCostService 
{
    /**
     * 查询projectCost
     * 
     * @param id projectCost主键
     * @return projectCost
     */
    public ProjectCost selectProjectCostById(Long id);

    /**
     * 查询projectCost列表
     * 
     * @param projectCost projectCost
     * @return projectCost集合
     */
    public List<ProjectCost> selectProjectCostList(ProjectCost projectCost);

    /**
     * 新增projectCost
     * 
     * @param projectCost projectCost
     * @return 结果
     */
    public int insertProjectCost(ProjectCost projectCost);

    /**
     * 修改projectCost
     * 
     * @param projectCost projectCost
     * @return 结果
     */
    public int updateProjectCost(ProjectCost projectCost);

    /**
     * 批量删除projectCost
     * 
     * @param ids 需要删除的projectCost主键集合
     * @return 结果
     */
    public int deleteProjectCostByIds(Long[] ids);

    /**
     * 删除projectCost信息
     * 
     * @param id projectCost主键
     * @return 结果
     */
    public int deleteProjectCostById(Long id);

    /**
     * 批量新增projectCost
     *
     * @param projectCosts projectCosts
     * @return 结果
     */
    boolean insertBatchProjectCost(List<ProjectCost> projectCosts);
}
